@@ -1,25 +1,26 @@
 /*
-  convenient routines for argument list handling
-
-   Copyright (C) Andrew Tridgell 2002
-   
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-   
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-   
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
+ * Copyright (C) 2002 Andrew Tridgell
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 3 of the License, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, write to the Free Software Foundation, Inc., 51
+ * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
 
 #include "ccache.h"
 
+#include <stdlib.h>
+#include <string.h>
+
 ARGS *args_init(int init_argc, char **init_args)
 {
 	ARGS *args;
@@ -34,6 +35,22 @@ ARGS *args_init(int init_argc, char **init_args)
 	return args;
 }
 
+ARGS *args_copy(ARGS *args)
+{
+	return args_init(args->argc, args->argv);
+}
+
+void args_free(ARGS *args)
+{
+	int i;
+	for (i = 0; i < args->argc; ++i) {
+		if (args->argv[i]) {
+			free(args->argv[i]);
+		}
+	}
+	free(args->argv);
+	free(args);
+}
 
 void args_add(ARGS *args, const char *s)
 {
@@ -57,7 +74,7 @@ void args_pop(ARGS *args, int n)
 void args_remove_first(ARGS *args)
 {
 	free(args->argv[0]);
-	memmove(&args->argv[0], 
+	memmove(&args->argv[0],
 		&args->argv[1],
 		args->argc * sizeof(args->argv[0]));
 	args->argc--;
@@ -67,7 +84,7 @@ void args_remove_first(ARGS *args)
 void args_add_prefix(ARGS *args, const char *s)
 {
 	args->argv = (char**)x_realloc(args->argv, (args->argc + 2) * sizeof(char *));
-	memmove(&args->argv[1], &args->argv[0], 
+	memmove(&args->argv[1], &args->argv[0],
 		(args->argc+1) * sizeof(args->argv[0]));
 	args->argv[0] = x_strdup(s);
 	args->argc++;
@@ -80,8 +97,8 @@ void args_strip(ARGS *args, const char *prefix)
 	for (i=0; i<args->argc; ) {
 		if (strncmp(args->argv[i], prefix, strlen(prefix)) == 0) {
 			free(args->argv[i]);
-			memmove(&args->argv[i], 
-				&args->argv[i+1], 
+			memmove(&args->argv[i],
+				&args->argv[i+1],
 				args->argc * sizeof(args->argv[i]));
 			args->argc--;
 		} else {
