@@ -1,45 +1,56 @@
 /*
-   Copyright (C) Andrew Tridgell 2002
-   
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-   
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-   
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
+ * Copyright (C) Andrew Tridgell 2002
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 3 of the License, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, write to the Free Software Foundation, Inc., 51
+ * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
 
 #include "ccache.h"
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/wait.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+#include <unistd.h>
 
 /*
   execute a compiler backend, capturing all output to the given paths
   the full path to the compiler to run is in argv[0]
 */
-int execute(char **argv, 
+int execute(char **argv,
 	    const char *path_stdout,
 	    const char *path_stderr)
 {
 	pid_t pid;
 	int status;
 
+	cc_log_executed_command(argv);
+
 	pid = fork();
 	if (pid == -1) fatal("Failed to fork");
-	
+
 	if (pid == 0) {
 		int fd;
 
 		unlink(path_stdout);
 		fd = open(path_stdout, O_WRONLY|O_CREAT|O_TRUNC|O_EXCL|O_BINARY, 0666);
 		if (fd == -1) {
-			exit(STATUS_NOCACHE);
+			exit(1);
 		}
 		dup2(fd, 1);
 		close(fd);
@@ -47,7 +58,7 @@ int execute(char **argv,
 		unlink(path_stderr);
 		fd = open(path_stderr, O_WRONLY|O_CREAT|O_TRUNC|O_EXCL|O_BINARY, 0666);
 		if (fd == -1) {
-			exit(STATUS_NOCACHE);
+			exit(1);
 		}
 		dup2(fd, 2);
 		close(fd);
@@ -68,7 +79,7 @@ int execute(char **argv,
 
 
 /*
-  find an executable by name in $PATH. Exclude any that are links to exclude_name 
+  find an executable by name in $PATH. Exclude any that are links to exclude_name
 */
 char *find_executable(const char *name, const char *exclude_name)
 {
@@ -85,12 +96,12 @@ char *find_executable(const char *name, const char *exclude_name)
 		path = getenv("PATH");
 	}
 	if (!path) {
-		cc_log("no PATH variable!?\n");
+		cc_log("No PATH variable");
 		return NULL;
 	}
 
 	path = x_strdup(path);
-	
+
 	/* search the path looking for the first compiler of the right name
 	   that isn't us */
 	for (tok=strtok(path,":"); tok; tok = strtok(NULL, ":")) {
@@ -106,7 +117,7 @@ char *find_executable(const char *name, const char *exclude_name)
 			if (S_ISLNK(st1.st_mode)) {
 				char *buf = x_realpath(fname);
 				if (buf) {
-					char *p = str_basename(buf);
+					char *p = basename(buf);
 					if (strcmp(p, exclude_name) == 0) {
 						/* its a link to "ccache" ! */
 						free(p);
@@ -127,3 +138,18 @@ char *find_executable(const char *name, const char *exclude_name)
 
 	return NULL;
 }
+
+void print_command(FILE *fp, char **argv)
+{
+	int i;
+	for (i = 0; argv[i]; i++) {
+		fprintf(fp, "%s%s",  (i == 0) ? "" : " ", argv[i]);
+	}
+	fprintf(fp, "\n");
+}
+
+void print_executed_command(FILE *fp, char **argv)
+{
+	fprintf(fp, "%s: executing ", MYNAME);
+	print_command(fp, argv);
+}
