@@ -35,9 +35,9 @@
  *    original.  Also, there is now a builtin-test, just compile with:
  *           gcc -DTEST_SNPRINTF -o snprintf snprintf.c -lm
  *    and run snprintf for results.
- * 
+ *
  *  Thomas Roessler <roessler@guug.de> 01/27/98 for mutt 0.89i
- *    The PGP code was using unsigned hexadecimal formats. 
+ *    The PGP code was using unsigned hexadecimal formats.
  *    Unfortunately, unsigned formats simply didn't work.
  *
  *  Michael Elkins <me@cs.hmc.edu> 03/05/98 for mutt 0.90.8
@@ -79,7 +79,7 @@
 /* only include stdio.h if we are not re-defining snprintf or vsnprintf */
 #include <stdio.h>
  /* make the compiler happy with an empty file */
- void dummy_snprintf(void) {} 
+ void dummy_snprintf(void) {}
 #else
 
 #ifdef HAVE_LONG_DOUBLE
@@ -94,7 +94,7 @@
 #define LLONG long
 #endif
 
-static size_t dopr(char *buffer, size_t maxlen, const char *format, 
+static size_t dopr(char *buffer, size_t maxlen, const char *format,
 		   va_list args);
 static void fmtstr(char *buffer, size_t *currlen, size_t maxlen,
 		    char *value, int flags, int min, int max);
@@ -150,21 +150,21 @@ static size_t dopr(char *buffer, size_t maxlen, const char *format, va_list args
 	int flags;
 	int cflags;
 	size_t currlen;
-	
+
 	state = DP_S_DEFAULT;
 	currlen = flags = cflags = min = 0;
 	max = -1;
 	ch = *format++;
-	
+
 	while (state != DP_S_DONE) {
-		if (ch == '\0') 
+		if (ch == '\0')
 			state = DP_S_DONE;
 
 		switch(state) {
 		case DP_S_DEFAULT:
-			if (ch == '%') 
+			if (ch == '%')
 				state = DP_S_FLAGS;
-			else 
+			else
 				dopr_outch (buffer, &currlen, maxlen, ch);
 			ch = *format++;
 			break;
@@ -211,7 +211,7 @@ static size_t dopr(char *buffer, size_t maxlen, const char *format, va_list args
 			if (ch == '.') {
 				state = DP_S_MAX;
 				ch = *format++;
-			} else { 
+			} else {
 				state = DP_S_MOD;
 			}
 			break;
@@ -256,7 +256,7 @@ static size_t dopr(char *buffer, size_t maxlen, const char *format, va_list args
 			switch (ch) {
 			case 'd':
 			case 'i':
-				if (cflags == DP_C_SHORT) 
+				if (cflags == DP_C_SHORT)
 					value = va_arg (args, int);
 				else if (cflags == DP_C_LONG)
 					value = va_arg (args, long int);
@@ -341,7 +341,7 @@ static size_t dopr(char *buffer, size_t maxlen, const char *format, va_list args
 				fmtstr (buffer, &currlen, maxlen, strvalue, flags, min, max);
 				break;
 			case 'p':
-				strvalue = va_arg (args, void *);
+				strvalue = (char *)va_arg(args, void *);
 				fmtint (buffer, &currlen, maxlen, (long) strvalue, 16, min, max, flags);
 				break;
 			case 'n':
@@ -387,12 +387,12 @@ static size_t dopr(char *buffer, size_t maxlen, const char *format, va_list args
 		}
 	}
 	if (maxlen != 0) {
-		if (currlen < maxlen - 1) 
+		if (currlen < maxlen - 1)
 			buffer[currlen] = '\0';
-		else if (maxlen > 0) 
+		else if (maxlen > 0)
 			buffer[maxlen - 1] = '\0';
 	}
-	
+
 	return currlen;
 }
 
@@ -411,11 +411,11 @@ static void fmtstr(char *buffer, size_t *currlen, size_t maxlen,
 
 	for (strln = 0; value[strln]; ++strln); /* strlen */
 	padlen = min - strln;
-	if (padlen < 0) 
+	if (padlen < 0)
 		padlen = 0;
-	if (flags & DP_F_MINUS) 
+	if (flags & DP_F_MINUS)
 		padlen = -padlen; /* Left Justify */
-	
+
 	while ((padlen > 0) && (cnt < max)) {
 		dopr_outch (buffer, currlen, maxlen, ' ');
 		--padlen;
@@ -444,12 +444,12 @@ static void fmtint(char *buffer, size_t *currlen, size_t maxlen,
 	int spadlen = 0; /* amount to space pad */
 	int zpadlen = 0; /* amount to zero pad */
 	int caps = 0;
-	
+
 	if (max < 0)
 		max = 0;
-	
+
 	uvalue = value;
-	
+
 	if(!(flags & DP_F_UNSIGNED)) {
 		if( value < 0 ) {
 			signvalue = '-';
@@ -461,7 +461,7 @@ static void fmtint(char *buffer, size_t *currlen, size_t maxlen,
 				signvalue = ' ';
 		}
 	}
-  
+
 	if (flags & DP_F_UP) caps = 1; /* Should characters be upper case? */
 
 	do {
@@ -481,7 +481,7 @@ static void fmtint(char *buffer, size_t *currlen, size_t maxlen,
 		zpadlen = MAX(zpadlen, spadlen);
 		spadlen = 0;
 	}
-	if (flags & DP_F_MINUS) 
+	if (flags & DP_F_MINUS)
 		spadlen = -spadlen; /* Left Justifty */
 
 #ifdef DEBUG_SNPRINTF
@@ -496,7 +496,7 @@ static void fmtint(char *buffer, size_t *currlen, size_t maxlen,
 	}
 
 	/* Sign */
-	if (signvalue) 
+	if (signvalue)
 		dopr_outch (buffer, currlen, maxlen, signvalue);
 
 	/* Zeros */
@@ -508,9 +508,9 @@ static void fmtint(char *buffer, size_t *currlen, size_t maxlen,
 	}
 
 	/* Digits */
-	while (place > 0) 
+	while (place > 0)
 		dopr_outch (buffer, currlen, maxlen, convert[--place]);
-  
+
 	/* Left Justified spaces */
 	while (spadlen < 0) {
 		dopr_outch (buffer, currlen, maxlen, ' ');
@@ -524,19 +524,19 @@ static LDOUBLE abs_val(LDOUBLE value)
 
 	if (value < 0)
 		result = -value;
-	
+
 	return result;
 }
 
 static LDOUBLE POW10(int exp)
 {
 	LDOUBLE result = 1;
-	
+
 	while (exp) {
 		result *= 10;
 		exp--;
 	}
-  
+
 	return result;
 }
 
@@ -547,7 +547,7 @@ static LLONG ROUND(LDOUBLE value)
 	intpart = (LLONG)value;
 	value = value - intpart;
 	if (value >= 0.5) intpart++;
-	
+
 	return intpart;
 }
 
@@ -580,7 +580,7 @@ static double my_modf(double x0, double *iptr)
 		ret = my_modf(x0-l*f, &i2);
 		(*iptr) = l*f + i2;
 		return ret;
-	} 
+	}
 
 	(*iptr) = l;
 	return x - (*iptr);
@@ -597,14 +597,14 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 	int iplace = 0;
 	int fplace = 0;
 	int padlen = 0; /* amount to pad */
-	int zpadlen = 0; 
+	int zpadlen = 0;
 	int caps = 0;
 	int index;
 	double intpart;
 	double fracpart;
 	double temp;
-  
-	/* 
+
+	/*
 	 * AIX manpage says the default is 0, but Solaris says the default
 	 * is 6, and sprintf on AIX defaults to 6
 	 */
@@ -632,8 +632,8 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 	 if (max == 0) ufvalue += 0.5; /* if max = 0 we must round */
 #endif
 
-	/* 
-	 * Sorry, we only support 16 digits past the decimal because of our 
+	/*
+	 * Sorry, we only support 16 digits past the decimal because of our
 	 * conversion method
 	 */
 	if (max > 16)
@@ -647,7 +647,7 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 	my_modf(temp, &intpart);
 
 	fracpart = ROUND((POW10(max)) * (ufvalue - intpart));
-	
+
 	if (fracpart >= POW10(max)) {
 		intpart++;
 		fracpart -= POW10(max);
@@ -684,16 +684,16 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 		if (fplace == 311) fplace--;
 	}
 	fconvert[fplace] = 0;
-  
+
 	/* -1 for decimal point, another -1 if we are printing a sign */
-	padlen = min - iplace - max - 1 - ((signvalue) ? 1 : 0); 
+	padlen = min - iplace - max - 1 - ((signvalue) ? 1 : 0);
 	zpadlen = max - fplace;
 	if (zpadlen < 0) zpadlen = 0;
-	if (padlen < 0) 
+	if (padlen < 0)
 		padlen = 0;
-	if (flags & DP_F_MINUS) 
+	if (flags & DP_F_MINUS)
 		padlen = -padlen; /* Left Justifty */
-	
+
 	if ((flags & DP_F_ZERO) && (padlen > 0)) {
 		if (signvalue) {
 			dopr_outch (buffer, currlen, maxlen, signvalue);
@@ -709,10 +709,10 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 		dopr_outch (buffer, currlen, maxlen, ' ');
 		--padlen;
 	}
-	if (signvalue) 
+	if (signvalue)
 		dopr_outch (buffer, currlen, maxlen, signvalue);
-	
-	while (iplace > 0) 
+
+	while (iplace > 0)
 		dopr_outch (buffer, currlen, maxlen, iconvert[--iplace]);
 
 #ifdef DEBUG_SNPRINTF
@@ -725,11 +725,11 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 	 */
 	if (max > 0) {
 		dopr_outch (buffer, currlen, maxlen, '.');
-		
-		while (fplace > 0) 
+
+		while (fplace > 0)
 			dopr_outch (buffer, currlen, maxlen, fconvert[--fplace]);
 	}
-	
+
 	while (zpadlen > 0) {
 		dopr_outch (buffer, currlen, maxlen, '0');
 		--zpadlen;
@@ -770,7 +770,7 @@ static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 {
 	size_t ret;
 	va_list ap;
-    
+
 	va_start(ap, fmt);
 	ret = vsnprintf(str, count, fmt, ap);
 	va_end(ap);
@@ -778,13 +778,13 @@ static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 }
 #endif
 
-#endif 
+#endif
 
 #ifndef HAVE_VASPRINTF
  int vasprintf(char **ptr, const char *format, va_list ap)
 {
 	int ret;
-	
+
 	ret = vsnprintf(0, 0, format, ap);
 	if (ret <= 0) return ret;
 
@@ -802,7 +802,7 @@ static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 {
 	va_list ap;
 	int ret;
-	
+
 	*ptr = 0;
 	va_start(ap, format);
 	ret = vasprintf(ptr, format, ap);
@@ -852,7 +852,7 @@ static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 		"-16.16f",
 		0
 	};
-	double fp_nums[] = { 6442452944.1234, -1.5, 134.21, 91340.2, 341.1234, 0203.9, 0.96, 0.996, 
+	double fp_nums[] = { 6442452944.1234, -1.5, 134.21, 91340.2, 341.1234, 0203.9, 0.96, 0.996,
 			     0.9996, 1.996, 4.136,  0};
 	char *int_fmt[] = {
 		"%-1.5d",
@@ -894,7 +894,7 @@ static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 			int l2 = snprintf(buf1, sizeof(buf1), fp_fmt[x], fp_nums[y]);
 			sprintf (buf2, fp_fmt[x], fp_nums[y]);
 			if (strcmp (buf1, buf2)) {
-				printf("snprintf doesn't match Format: %s\n\tsnprintf = [%s]\n\t sprintf = [%s]\n", 
+				printf("snprintf doesn't match Format: %s\n\tsnprintf = [%s]\n\t sprintf = [%s]\n",
 				       fp_fmt[x], buf1, buf2);
 				fail++;
 			}
@@ -912,7 +912,7 @@ static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 			int l2 = snprintf(buf1, sizeof(buf1), int_fmt[x], int_nums[y]);
 			sprintf (buf2, int_fmt[x], int_nums[y]);
 			if (strcmp (buf1, buf2)) {
-				printf("snprintf doesn't match Format: %s\n\tsnprintf = [%s]\n\t sprintf = [%s]\n", 
+				printf("snprintf doesn't match Format: %s\n\tsnprintf = [%s]\n\t sprintf = [%s]\n",
 				       int_fmt[x], buf1, buf2);
 				fail++;
 			}
@@ -930,7 +930,7 @@ static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 			int l2 = snprintf(buf1, sizeof(buf1), str_fmt[x], str_vals[y]);
 			sprintf (buf2, str_fmt[x], str_vals[y]);
 			if (strcmp (buf1, buf2)) {
-				printf("snprintf doesn't match Format: %s\n\tsnprintf = [%s]\n\t sprintf = [%s]\n", 
+				printf("snprintf doesn't match Format: %s\n\tsnprintf = [%s]\n\t sprintf = [%s]\n",
 				       str_fmt[x], buf1, buf2);
 				fail++;
 			}
