@@ -1,38 +1,46 @@
 /*
-   Copyright (C) Andrew Tridgell 2002
-   
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-   
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-   
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Copyright (C) 2002 Andrew Tridgell
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 3 of the License, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, write to the Free Software Foundation, Inc., 51
+ * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
+
 /*
-  C/C++ unifier
-
-  the idea is that changes that don't affect the resulting C code
-  should not change the hash. This is achieved by folding white-space
-  and other non-semantic fluff in the input into a single unified format.
-
-  This unifier was design to match the output of the unifier in
-  compilercache, which is flex based. The major difference is that
-  this unifier is much faster (about 2x) and more forgiving of
-  syntactic errors. Continuing on syntactic errors is important to
-  cope with C/C++ extensions in the local compiler (for example,
-  inline assembly systems).  
-*/
+ * C/C++ unifier
+ *
+ * The idea is that changes that don't affect the resulting C code should not
+ * change the hash. This is achieved by folding white-space and other
+ * non-semantic fluff in the input into a single unified format.
+ *
+ * This unifier was design to match the output of the unifier in compilercache,
+ * which is flex based. The major difference is that this unifier is much
+ * faster (about 2x) and more forgiving of syntactic errors. Continuing on
+ * syntactic errors is important to cope with C/C++ extensions in the local
+ * compiler (for example, inline assembly systems).
+ */
 
 #include "ccache.h"
 
-static char *s_tokens[] = {
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/mman.h>
+#include <ctype.h>
+#include <fcntl.h>
+#include <string.h>
+#include <unistd.h>
+
+static const char *const s_tokens[] = {
 	"...",	">>=",	"<<=",	"+=",	"-=",	"*=",	"/=",	"%=",	"&=",	"^=",
 	"|=",	">>",	"<<",	"++",	"--",	"->",	"&&",	"||",	"<=",	">=",
 	"==",	"!=",	";",	"{",	"<%",	"}",	"%>",	",",	":",	"=",
@@ -53,7 +61,7 @@ static char *s_tokens[] = {
 static struct {
 	unsigned char type;
 	unsigned char num_toks;
-	char *toks[7];
+	const char *toks[7];
 } tokens[256];
 
 /* build up the table used by the unifier */
@@ -94,29 +102,29 @@ static void build_table(void)
 }
 
 /* buffer up characters before hashing them */
-static void pushchar(unsigned char c)
+static void pushchar(struct mdfour *hash, unsigned char c)
 {
 	static unsigned char buf[64];
-	static int len;
+	static size_t len;
 
 	if (c == 0) {
 		if (len > 0) {
-			hash_buffer((char *)buf, len);
+			hash_buffer(hash, (char *)buf, len);
 			len = 0;
 		}
-		hash_buffer(NULL, 0);
+		hash_buffer(hash, NULL, 0);
 		return;
 	}
 
 	buf[len++] = c;
 	if (len == 64) {
-		hash_buffer((char *)buf, len);
+		hash_buffer(hash, (char *)buf, len);
 		len = 0;
 	}
 }
 
 /* hash some C/C++ code after unifying */
-static void unify(unsigned char *p, size_t size)
+static void unify(struct mdfour *hash, unsigned char *p, size_t size)
 {
 	size_t ofs;
 	unsigned char q;
@@ -133,10 +141,10 @@ static void unify(unsigned char *p, size_t size)
 				ofs++;
 			} else {
 				do {
-					pushchar(p[ofs]);
+					pushchar(hash, p[ofs]);
 					ofs++;
 				} while (ofs < size && p[ofs] != '\n');
-				pushchar('\n');
+				pushchar(hash, '\n');
 				ofs++;
 			}
 			continue;
@@ -144,40 +152,40 @@ static void unify(unsigned char *p, size_t size)
 
 		if (tokens[p[ofs]].type & C_ALPHA) {
 			do {
-				pushchar(p[ofs]);
+				pushchar(hash, p[ofs]);
 				ofs++;
-			} while (ofs < size && 
+			} while (ofs < size &&
 				 (tokens[p[ofs]].type & (C_ALPHA|C_DIGIT)));
-			pushchar('\n');
+			pushchar(hash, '\n');
 			continue;
 		}
 
 		if (tokens[p[ofs]].type & C_DIGIT) {
 			do {
-				pushchar(p[ofs]);
+				pushchar(hash, p[ofs]);
 				ofs++;
-			} while (ofs < size && 
+			} while (ofs < size &&
 				 ((tokens[p[ofs]].type & C_DIGIT) || p[ofs] == '.'));
 			if (ofs < size && (p[ofs] == 'x' || p[ofs] == 'X')) {
 				do {
-					pushchar(p[ofs]);
+					pushchar(hash, p[ofs]);
 					ofs++;
 				} while (ofs < size && (tokens[p[ofs]].type & C_HEX));
 			}
 			if (ofs < size && (p[ofs] == 'E' || p[ofs] == 'e')) {
-				pushchar(p[ofs]);
+				pushchar(hash, p[ofs]);
 				ofs++;
-				while (ofs < size && 
+				while (ofs < size &&
 				       (tokens[p[ofs]].type & (C_DIGIT|C_SIGN))) {
-					pushchar(p[ofs]);
+					pushchar(hash, p[ofs]);
 					ofs++;
 				}
 			}
 			while (ofs < size && (tokens[p[ofs]].type & C_FLOAT)) {
-				pushchar(p[ofs]);
+				pushchar(hash, p[ofs]);
 				ofs++;
 			}
-			pushchar('\n');
+			pushchar(hash, '\n');
 			continue;
 		}
 
@@ -187,20 +195,20 @@ static void unify(unsigned char *p, size_t size)
 			} while (ofs < size && (tokens[p[ofs]].type & C_SPACE));
 			continue;
 		}
-			
+
 		if (tokens[p[ofs]].type & C_QUOTE) {
 			q = p[ofs];
-			pushchar(p[ofs]);
+			pushchar(hash, p[ofs]);
 			do {
 				ofs++;
 				while (ofs < size-1 && p[ofs] == '\\') {
-					pushchar(p[ofs]);
-					pushchar(p[ofs+1]);
+					pushchar(hash, p[ofs]);
+					pushchar(hash, p[ofs+1]);
 					ofs+=2;
 				}
-				pushchar(p[ofs]);
+				pushchar(hash, p[ofs]);
 			} while (ofs < size && p[ofs] != q);
-			pushchar('\n');
+			pushchar(hash, '\n');
 			ofs++;
 			continue;
 		}
@@ -213,10 +221,10 @@ static void unify(unsigned char *p, size_t size)
 				if (size >= ofs+len && memcmp(&p[ofs], s, len) == 0) {
 					int j;
 					for (j=0;s[j];j++) {
-						pushchar(s[j]);
+						pushchar(hash, s[j]);
 						ofs++;
 					}
-					pushchar('\n');
+					pushchar(hash, '\n');
 					break;
 				}
 			}
@@ -225,26 +233,26 @@ static void unify(unsigned char *p, size_t size)
 			}
 		}
 
-		pushchar(p[ofs]);
-		pushchar('\n');
+		pushchar(hash, p[ofs]);
+		pushchar(hash, '\n');
 		ofs++;
 	}
-	pushchar(0);
+	pushchar(hash, 0);
 }
 
 
-/* hash a file that consists of preprocessor output, but remove any line 
+/* hash a file that consists of preprocessor output, but remove any line
    number information from the hash
 */
-int unify_hash(const char *fname)
+int unify_hash(struct mdfour *hash, const char *fname)
 {
 	int fd;
-	struct stat st;	
+	struct stat st;
 	char *map;
 
 	fd = open(fname, O_RDONLY|O_BINARY);
 	if (fd == -1 || fstat(fd, &st) != 0) {
-		cc_log("Failed to open preprocessor output %s\n", fname);
+		cc_log("Failed to open preprocessor output %s", fname);
 		stats_update(STATS_PREPROCESSOR);
 		return -1;
 	}
@@ -253,17 +261,16 @@ int unify_hash(const char *fname)
            lines in preprocessor output. I have seen lines of over
            100k in length, so this is well worth it */
 	map = mmap(NULL, st.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
+	close(fd);
 	if (map == (char *)-1) {
-		cc_log("Failed to mmap %s\n", fname);
+		cc_log("Failed to mmap %s", fname);
 		return -1;
 	}
-	close(fd);
 
 	/* pass it through the unifier */
-	unify((unsigned char *)map, st.st_size);
+	unify(hash, (unsigned char *)map, st.st_size);
 
 	munmap(map, st.st_size);
 
 	return 0;
 }
-
